%
% LotkaVolterra equations
% https://en.wikipedia.org/wiki/LotkaVolterra_equations
%
% Competitive LotkaVolterra equations
% https://en.wikipedia.org/wiki/Competitive_LotkaVolterra_equations
%
% Generalized LotkaVolterra equation
% https://en.wikipedia.org/wiki/Generalized_LotkaVolterra_equation
%
clear all
close all

T=500;              %equivalent of 5 seconds (T=secs*1000/dt)
dim1=2;              %number of units per layer
dim2=4;
dim3=3;

A= zeros(T,dim1);
B= zeros(T,dim2);
C= zeros(T,dim3);

A(1,:)=[80 40];
B(1,:)=[10 15 5 20];
C(1,:)=[0.5 0.5 0.5];

%Prey-Predator parameters
par=[0.1 0.003 0.06 0.0012];

%Precapita growth rate in generalised
rb=[1 1 1 1];
rc=[1 1 1];

%matrix of reciprocal effects
alphab=[0.3    0.6    0.2    0.9
        0.3    0.4    0.4    0.0
        0.4    0.1    0.3    0.7
        0.0    0.4    0.9    0.2]*0.1;
alphac =ones(dim3)*1.5;

%carrying capacity
kb=ones(1,dim2)*1;
kc=ones(1,dim3)*1;

sec=7;
for t=2:T
 
    if t>T/sec && t<T/sec*2
%     alphab=[0.3    0.6    0.2    0.9
%             0.6    0.3    0.9    0.2
%             0.9    0.2    0.3    0.6
%             0.0    0.4    0.9    0.3]*0.1;
        alphac(1,1)=1.4;
        alphac(2,2)=1.2;
        alphac(3,3)=1.0;
    elseif t>T/sec*2 && t<T/sec*3
    alphab=[0.3    0.6    0.2    0.9
            0.6    0.3    0.9    0.2
            0.9    0.2    0.3    0.6
            0.2    0.9    0.6    0.3]*0.1;
        alphac(1,1)=2.0;
        alphac(2,2)=1.0;
        alphac(3,3)=3.0;
    elseif t>T/sec*3 && t<T/sec*4
    alphac =[1.0  1.2   0.4
             0.4   0.9   1.2
             1.2   0.4   1.1];
    elseif t>T/sec*4 && t<T/sec*5
    alphab=[0.3    0.6    0.2    0.9
            0.3    0.4    0.4    0.0
            0.4    0.1    0.2    0.7
            0.0    0.4    0.9    0.2]*0.05;
    alphac =[0.8  1.2   0.4
             0.4   0.78   1.2
             1.2   0.4   0.76];
    elseif t>T/sec*5 && t<T/sec*6
    alphac =[0.7  1.2   0.4
             0.0   0.8   0.0
             0.4   1.2   0.66];
    elseif t>T/sec*6 && t<=T/sec*7
        alphac=[1.2  0.3  0.2
                0.3  1.0  0.3
                0.2  0.5  1.4];
    end
    A=lotkavolterrapp(t, par, A);
    B=lotkavolterracomp(t, rb, alphab, kb, B);
    C=lotkavolterracomp(t, rc, alphac, kc, C);
    
end

h=figure;
screen_size=get(0,'ScreenSize');
screen_size(1:2)=screen_size(3:4)*1/10;
screen_size(3:4)=[1600  1000];
set(h,'Position',screen_size)

subplot(3,1,1)
plot (A(:,1),'LineWidth',3)
hold on
plot (A(:,2),'LineWidth',3, 'Color' ,[0.8 0.3 0.2])
hold off
title('Prey-Predator', 'FontSize', 18)
legend('Prey', 'predator')

subplot(3,1,2)
plot (B(:,1),'LineWidth',3)
hold on
plot (B(:,2),'LineWidth',3, 'Color' ,[0.8 0.3 0.2])
plot (B(:,3),'LineWidth',3, 'Color' ,[0.2 0.8 0.3])
plot (B(:,4),'LineWidth',3, 'Color' ,[0.8 0.3 0.8])
hold off
title('Lotka-Volterra Comp', 'FontSize', 18)
legend('Species1', 'Species2', 'Species3', 'Species4')

subplot(3,1,3)
plot (C(:,1),'LineWidth',3)
hold on
plot (C(:,2),'LineWidth',3, 'Color' ,[0.8 0.3 0.2])
plot (C(:,3),'LineWidth',3, 'Color' ,[0.2 0.8 0.3])
hold off
title('Lotka-Volterra Generalised', 'FontSize', 18)
legend('Species1', 'Species2', 'Species3')

